@@ -2,4 +2,6 @@ from .imports import *
 from .test import *
 from .basics import *
 from .xtras import *
+from .parallel import *
+from .net import *
 
